/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2010-2012 University of Bonn. All rights reserved.
 * 
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * GraphEdge.cpp
 *
 *  Created on: Feb 25, 2011
 *      Author: heber
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include <string>

#include "Bond/GraphEdge.hpp"
#include "CodePatterns/Log.hpp"
#include "CodePatterns/Verbose.hpp"

GraphEdge::GraphEdge() :
  Cyclic(false),
  Type(Undetermined),
  Used(white)
{}

GraphEdge::~GraphEdge()
{}

enum GraphEdge::Shading GraphEdge::IsUsed()
{
  return Used;
};

bool GraphEdge::MarkUsed(const enum GraphEdge::Shading color)
{
  if (Used == black) {
    ELOG(1, "GraphEdge " << this << " was already marked black!.");
    return false;
  } else {
    Used = color;
    return true;
  }
};

void GraphEdge::ResetUsed()
{
  Used = white;
};

std::string GraphEdge::getColorName(enum Shading color)
{
  switch (color) {
    case white:
      return "white";
      break;
    case lightgray:
      return "lightgray";
      break;
    case darkgray:
      return "darkgray";
      break;
    case black:
      return "black";
      break;
    default:
      return "uncolored";
      break;
  };
}
